@@ -2,19 +2,16 @@ from django.core.urlresolvers import reverse
 
 
 class RequiresLogin(object):
-    """
-    Test mixin for views that require a user to be logged in.
-    """
-
     def test_getRedirectsToLoginIfUserNotLoggedIn(self):
         self.logOut()
-        response = self.client.get(self.url)
-        self.assertRedirects(response, reverse('account_login') + '?next={}'.format(self.url))
+        url = self.get_url()
+        response = self.client.get(url)
+        self.assertRedirects(response, reverse('account_login') + '?next={}'.format(url))
 
     def test_getReturnsStatusOkForLoggedInUsers(self):
         if not self.loggedInUser:
             user = self.createUser()
             self.logInAs(user)
-        response = self.client.get(self.url)
-        self.assertResponseStatusIsOk(response)
+        self.get()
+        self.assertResponseStatusIsOk(self.response)
 
